==> ckeditor_infocard-1.0.0.tar.gz: ckeditor_infocard/README.md <==
CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Requirements
 * Installation
 * Configuration
 * Usage
 * Maintainers


INTRODUCTION
------------

Adds a button to CKEditor for inserting and editing InfoCards. An InfoCard is an expandable and collapsible card linked to a part of text. If an
existing span tag is selected, the context menu also contains a link to edit the
InfoCards.

 * For a full description of the module, visit the project page:
   https://www.drupal.org/project/ckeditor_infocard

 * To submit bug reports and feature suggestions, or to track changes:
   https://www.drupal.org/project/issues/ckeditor_infocard


REQUIREMENTS
------------

This module requires no modules outside of Drupal core.


INSTALLATION
------------

 * Install the CKEditor InfoCard module as you would normally install a
   contributed Drupal module.
   Visit https://www.drupal.org/node/1897420 for further information.


CONFIGURATION
-------------

    1. Navigate to Administration > Extend and enable the module.
    2. Navigate to Administration > Configuration > Content authoring > Text
       formats and editors.
    3. Move the CKEditor InfoCard icon into the active toolbar. The button
       is available in the CKEditor toolbar configuration of text formats if you
       set ckeditor as text editor.
    4. Enable the filter 'Limit allowed HTML tags and correct faulty HTML'. Add
       the title attribute to the allowed HTML abbr tag, if you want to allow an
       explanation of the abbreviation.


USAGE
-----

 * Select the abbreviation you want to tag. Click the ckeditor abbreviation icon and fill in the fields in the
   opening dialog.
 * To edit a tagged abbreviation place the cursor within the abbreviation text and click the ckeditor abbreviation icon.
   Or open the context menu by right-clicking on your mouse and select "Edit Abbreviation".
 * To remove an abbreviation title attribute, delete the explanation in the ckeditor abbreviation dialog.
   In order to untag an abbreviation, delete the abbreviation in the ckeditor abbreviation dialog.


MAINTAINERS
-----------

 * Simon Antonides (sianto_synetic)


Supporting organizations:

 * Synetic - https://synetic.nl


CREDITS
-------
From original package: CKEditor Abbreviation

 * Richard Papp (boromino) - https://www.drupal.org/u/boromino
 * LakeDrops - https://www.drupal.org/lakedrops

==> ckeditor_infocard-1.0.1.tar.gz: ckeditor_infocard/README.md <==
CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Requirements
 * Installation
 * Configuration
 * Usage
 * Maintainers


INTRODUCTION
------------

Adds a button to CKEditor for inserting and editing InfoCards. An InfoCard is an expandable and collapsible card linked to a part of text. If an
existing span tag is selected, the context menu also contains a link to edit the
InfoCards.

 * For a full description of the module, visit the project page:
   https://www.drupal.org/project/ckeditor_infocard

 * To submit bug reports and feature suggestions, or to track changes:
   https://www.drupal.org/project/issues/ckeditor_infocard


REQUIREMENTS
------------

This module requires no modules outside of Drupal core.


INSTALLATION
------------

 * Install the CKEditor InfoCard module as you would normally install a
   contributed Drupal module.
   Visit https://www.drupal.org/node/1897420 for further information.


CONFIGURATION
-------------

    1. Navigate to Administration > Extend and enable the module.
    2. Navigate to Administration > Configuration > Content authoring > Text
       formats and editors.
    3. Move the CKEditor InfoCard icon into the active toolbar. The button
       is available in the CKEditor toolbar configuration of text formats if you
       set ckeditor as text editor.
    4. Enable the filter 'Limit allowed HTML tags and correct faulty HTML'. Add
       the data-content attribute and class="js-infoCard" to the allowed HTML span tag, if you want to allow an
       explanation of the InfoCard.


USAGE
-----

 * Select the text you want to tag. Click the CKEditor InfoCard icon and fill in the fields in the
   opening dialog.
 * To edit a tagged InfoCard place the cursor within the InfoCard text and click the CKEditor InfoCard icon.
   Or open the context menu by right-clicking on your mouse and select "Edit InfoCard".
 * To remove an InfoCard title attribute, delete the explanation in the CKEditor InfoCard dialog.
   In order to untag an InfoCard, delete the InfoCard in the CKEditor InfoCard dialog.


MAINTAINERS
-----------

 * Simon Antonides (sianto_synetic)


Supporting organizations:

 * Synetic - https://synetic.nl


CREDITS
-------
From original package: CKEditor Abbreviation

 * Richard Papp (boromino) - https://www.drupal.org/u/boromino
 * LakeDrops - https://www.drupal.org/lakedrops
